@@ -19,7 +19,13 @@ class Venue():
 
         #ensure that the venue path is on sys.path
         self.VENUE_PATH in sys.path or sys.path.insert(0,self.VENUE_PATH)
+        #load the django settings
         self.get_settings()
+        #get this venue's acts
+        try:
+            self.get_acts()
+        except:
+            pass
 
     def get_settings(self):
         """ import the venue's settings.py"""
